==> algorithmic-0.0.9.tar.gz: ROADMAP.md <==
# Roadmaap

## Searching Algorithms

- [x] Linear search
- [x] Binary search
- [x] Lower-bound / Upper-bound

## Sorting Algorithms

- Exchange sorts
  - [x] Bubble sort
  - [x] Cocktail Shaker sort
  - [x] Comb sort
  - [x] Gnome sort
  - [x] Quicksort (Haore scheme)
  - [x] Quicksort (Lomuto scheme)
  - [ ] Quicksort (Dual pivot)
  - [ ] Quicksort (Multi pivot)
- Selection sorts
  - [x] Selection sort
  - [ ] Heapsort
- Insertion sorts
  - [x] Insertion sort
  - [ ] Shell sort
- [x] Merge sort
- Non-comparison sorts
  - [x] Counting sort
  - [x] Radix sort
  - [ ] Pigeonhole sort
  - [ ] Bucket sort
- Hybrid sorts
  - [ ] Introsort
  - [ ] Timsort
  - [ ] Flash sort
  - [ ] Merge-insertion sort
- Others
  - [ ] Cycle sort
  - [ ] Samplesort
  - [ ] Topological sort
- [ ] Generic sorting algorithm using the best ones

## Strings

- String metric
  - [ ] Jaro-Winker distance
  - [x] Levenshtein distance
  - [ ] Damerau-Levenshtein distance
  - [ ] Lee distance
  - [ ] Hamming distance
  - [ ] Wagner-fischer algorithm
  - [ ] Bitap algorithm
  - [ ] Gestalt pattern matching
  - [ ] Approximate string matching
- Subsequences
  - [ ] LCS (Longest common subsequence)
  - [ ] LIS (Longest increasing subsequence)
  - [ ] Kadane's algorithm
  - [ ] Shortest common supersquence
- String searching
  - [ ] Naive pattern matching
  - [ ] KMP (Knuth-Morris-Pratt) algorithm
  - [ ] Rabin-Karp algorithm
  - [ ] Boyer-Moore string-search algorithm
  - [ ] Boyer-Moore-Horspool algorithm
  - [ ] Zhu-Takaoka string matching algorithm
- Multiple string searching
  - [ ] Aho-Corasick algorithm
  - [ ] Commentz-Walter algorithm
- Sequence alignment
  - [ ] Hirschberg's algorithm
  - [ ] Needleman-Wunsch algorithm
  - [ ] Smith-Waterman algorithm
- Data structures
  - [ ] Trie tree
  - [ ] Hash Trie tree
  - [ ] Suffix tree
  - [ ] Suffix array
  - [ ] Suffix automaton
  - [ ] Rope
  - [ ] Finite automaton (DAFSA)
- Others
  - [ ] Manacher's algorithm

## Data Structures

- Abstract
  - [ ] Multimap
  - [ ] Stack
  - [ ] Queue
  - [ ] Double Ended Queue
  - [ ] Priority Queue
  - [ ] Double Ended Priority Queue
  - [ ] Multiset
  - [ ] Disjoint set
- Arrays
  - [ ] Bit array
  - [ ] Circular Buffer
- Linked
  - [ ] Linked List
  - [ ] Unrolled Linked List
  - [ ] XOR Linked List
  - [ ] Asssociation List
  - [ ] Skip List
- Graphs
  - [ ] Graph
  - [ ] Weighted Graph
  - [ ] Directed Acyclic Graph
  - [ ] Directed Acyclic Graph
  - [ ] Binary Decision Graph
- Trees
  - [ ] Tree
  - [ ] B-tree
  - [ ] BST (Binary search tree)
  - [ ] AA BST
  - [ ] AVL BST
  - [ ] Red-Black BST
  - [ ] Self-balancing BST
  - [ ] Splay BST
  - [ ] Heap
  - [ ] Binary Heap
  - [ ] Binomial Heap
  - [ ] Fibonacci Heap
  - [ ] R-tree
  - [ ] R* tree
  - [ ] R+ tree
  - [ ] Hilbert R-tree
  - [ ] Ternary search tree

## Mathematics

> Still not certain what to include here. This list will be updated soon.

- Divisors
  - [ ] Euclidean GCD
  - [ ] Extended Euclidean algorithm
  - [ ] Stein's Binary GCD
  - [ ] Lehmer's GCD
  - [ ] LCM
- Primes
  - [ ] Lucas primality test
  - [ ] Fermat primality test
  - [ ] Miller-Rabin primality test
  - [ ] Elliptic curve primality test
  - [ ] AKS (Agrawal–Kayal–Saxena) primality test
  - [ ] Baillie–PSW primality test
  - [ ] Quadratic Frobenius test
  - [ ] Solovay–Strassen primality test
  - [ ] Sieve of Atkin
  - [ ] Sieve of Erastosthenes
  - [ ] Sieve of Sundaram
  - [ ] Wheel factorization
- Factors
- Equations
- Interpolation and extrapolation
- Multiplication algorithms
- Division algorithms
- Modular square root
- Root-finding algorithms
- Data structures
  - [ ] Big Integer
  - [ ] Big Decimal
  - [ ] Matrix
  - [ ] Vector
  - [ ] Point
  - [ ] Line
  - [ ] Triangle
  - [ ] Rectangle
  - [ ] Circle
  - [ ] Polygon
- Geometry
  - [ ] Closest pair
  - [ ] Collison detection
  - [ ] Cone algorithm
  - [ ] Convex Hull
- Linear algebra
- Monte Carlo method
- Computation of PI
- Matrix multiplication

## Greedy
- [ ] Huffman coding
- [ ] Job sequencing
- MST (Minimum Spanning Tree)
- Prim's MST
- Boruvka's MST
- SPA (Shortest path algorithm)
- Dijkastra's SPA
- Max Flow algorithms
- Huffmaan decoding
- Acitivity selection
- Minimum product subset
- Bin packing
- Graph coloring
- Travelling salesman
- Branch and Bound

==> algorithmic-0.0.10.tar.gz: ROADMAP.md <==
# Roadmaap

## Searching Algorithms

- [x] Linear search
- [x] Binary search
- [x] Lower-bound / Upper-bound

## Sorting Algorithms

- Exchange sorts
  - [x] Bubble sort
  - [x] Cocktail Shaker sort
  - [x] Comb sort
  - [x] Gnome sort
  - [x] Quicksort (Haore scheme)
  - [x] Quicksort (Lomuto scheme)
  - [ ] Quicksort (Dual pivot)
  - [ ] Quicksort (Multi pivot)
- Selection sorts
  - [x] Selection sort
  - [ ] Heapsort
- Insertion sorts
  - [x] Insertion sort
  - [ ] Shell sort
- [x] Merge sort
- Non-comparison sorts
  - [x] Counting sort
  - [x] Radix sort
  - [ ] Pigeonhole sort
  - [ ] Bucket sort
- Hybrid sorts
  - [ ] Introsort
  - [ ] Timsort
  - [ ] Flash sort
  - [ ] Merge-insertion sort
- Others
  - [ ] Cycle sort
  - [ ] Samplesort
  - [ ] Topological sort
- [ ] Generic sorting algorithm using the best ones

## Strings

<!--
https://anhaidgroup.github.io/py_stringmatching/v0.3.x/OverlapCoefficient.html
-->

- String metric
  - [x] Levenshtein distance
  - [x] Damerau-Levenshtein distance
  - [x] Optimal string alignment distance
  - [x] Lee distance
  - [x] Hamming distance
  - [x] Longest Common Subsequence Length
  - [ ] Longest Common Substring Size
  - [ ] Longest Increasing Subsequence Length
  - [x] Tversky index
  - [x] Sorensen-Dice coefficient
  - [x] Jaccard similary + distance
  - [ ] Needleman Wunsch
  - [ ] Monge Elkan
  - [x] Jaro similarity & distance
  - [x] Jaro-Winkler similarity / distance
  - [ ] Block Distance / L1 Distance / Manhattan distance
  - [ ] Simple Matching Coefficient (SMC)
- Subsequences
  - [ ] LCS (Longest common subsequence)
  - [ ] LIS (Longest increasing subsequence)
  - [ ] Kadane's algorithm
  - [ ] Shortest common supersquence
- String searching
  - [ ] Naive pattern matching
  - [ ] KMP (Knuth-Morris-Pratt) algorithm
  - [ ] Rabin-Karp algorithm
  - [ ] Boyer-Moore string-search algorithm
  - [ ] Boyer-Moore-Horspool algorithm
  - [ ] Zhu-Takaoka string matching algorithm
- Multiple string searching
  - [ ] Aho-Corasick algorithm
  - [ ] Commentz-Walter algorithm
- Sequence alignment
  - [ ] Hirschberg's algorithm
  - [ ] Needleman-Wunsch algorithm
  - [ ] Smith-Waterman algorithm
- Data structures
  - [ ] Trie tree
  - [ ] Hash Trie tree
  - [ ] Suffix tree
  - [ ] Suffix array
  - [ ] Suffix automaton
  - [ ] Rope
  - [ ] Finite automaton (DAFSA)
- Others
  - [ ] Manacher's algorithm

## Data Structures

- Abstract
  - [ ] Multimap
  - [ ] Stack
  - [ ] Queue
  - [ ] Double Ended Queue
  - [ ] Priority Queue
  - [ ] Double Ended Priority Queue
  - [ ] Multiset
  - [ ] Disjoint set
- Arrays
  - [ ] Bit array
  - [ ] Circular Buffer
- Linked
  - [ ] Linked List
  - [ ] Unrolled Linked List
  - [ ] XOR Linked List
  - [ ] Asssociation List
  - [ ] Skip List
- Graphs
  - [ ] Graph
  - [ ] Weighted Graph
  - [ ] Directed Acyclic Graph
  - [ ] Directed Acyclic Graph
  - [ ] Binary Decision Graph
- Trees
  - [ ] Tree
  - [ ] B-tree
  - [ ] BST (Binary search tree)
  - [ ] AA BST
  - [ ] AVL BST
  - [ ] Red-Black BST
  - [ ] Self-balancing BST
  - [ ] Splay BST
  - [ ] Heap
  - [ ] Binary Heap
  - [ ] Binomial Heap
  - [ ] Fibonacci Heap
  - [ ] R-tree
  - [ ] R\* tree
  - [ ] R+ tree
  - [ ] Hilbert R-tree
  - [ ] Ternary search tree
  - [ ] Interval tree

## Mathematics

> Still not certain what to include here. This list will be updated soon.

- Divisors
  - [ ] Euclidean GCD
  - [ ] Extended Euclidean algorithm
  - [ ] Stein's Binary GCD
  - [ ] Lehmer's GCD
  - [ ] LCM
- Primes
  - [ ] Lucas primality test
  - [ ] Fermat primality test
  - [ ] Miller-Rabin primality test
  - [ ] Elliptic curve primality test
  - [ ] AKS (Agrawal–Kayal–Saxena) primality test
  - [ ] Baillie–PSW primality test
  - [ ] Quadratic Frobenius test
  - [ ] Solovay–Strassen primality test
  - [ ] Sieve of Atkin
  - [ ] Sieve of Erastosthenes
  - [ ] Sieve of Sundaram
  - [ ] Wheel factorization
- Factors
- Equations
- Interpolation and extrapolation
- Multiplication algorithms
- Division algorithms
- Modular square root
- Root-finding algorithms
- Data structures
  - [ ] Big Integer
  - [ ] Big Decimal
  - [ ] Matrix
  - [ ] Vector
  - [ ] Point
  - [ ] Line
  - [ ] Triangle
  - [ ] Rectangle
  - [ ] Circle
  - [ ] Polygon
- Geometry
  - [ ] Closest pair
  - [ ] Collison detection
  - [ ] Cone algorithm
  - [ ] Convex Hull
- Linear algebra
- Monte Carlo method
- Computation of PI
- Matrix multiplication

## Greedy

- [ ] Huffman coding
- [ ] Job sequencing
- MST (Minimum Spanning Tree)
- Prim's MST
- Boruvka's MST
- SPA (Shortest path algorithm)
- Dijkastra's SPA
- Max Flow algorithms
- Huffmaan decoding
- Acitivity selection
- Minimum product subset
- Bin packing
- Graph coloring
- Travelling salesman
- Branch and Bound
